import request from '@/utils/request'

// 财务数据-左下-农村集体资源情况
export function resourceAssetsStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/resourceAssetsStatistics',
    method: 'get',
    params: parms,
  });
}

// 财务数据-左上-农村集体资金情况
export function deptFundStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/deptFundStatistics',
    method: 'get',
    params: parms,
  });
}

// 财务数据-中下
export function financeSummary (parms) {
  return request({
    url: '/api/home/finance1/v2/financeSummary',
    method: 'get',
    params: parms,
  });
}

// 财务数据-中上
export function financeSummaryOverview (parms) {
  return request({
    url: '/api/home/finance1/v2/financeSummaryOverview',
    method: 'get',
    params: parms,
  });
}

// 财务数据-左中-农村集体资产情况
export function assetsStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/assetsStatistics',
    method: 'get',
    params: parms,
  });
}

// 财务数据-右上-集体经营性收入月度变动曲线
export function incomeMonthStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/incomeMonthStatistics',
    method: 'get',
    params: parms,
  });
}

// 财务数据-右中-集体经营性收入村居排行榜
export function incomeBookRank (parms) {
  return request({
    url: '/api/home/finance1/v2/incomeBookRank',
    method: 'get',
    params: parms,
  });
}

// 财务数据-右中-集体经营性收入村居排行榜
export function incomeTownRank (parms) {
  return request({
    url: '/api/home/finance1/v2/incomeTownRank',
    method: 'get',
    params: parms,
  });
}

// 预警中心-左1-村集体资金情况
export function collectiveFundSummary (parms) {
  return request({
    url: '/api/home/finance1/v2/collectiveFundSummary',
    method: 'get',
    params: parms,
  });
}

// 预警中心-中1-村集体资产情况
export function collectiveAssetSummary (parms) {
  return request({
    url: '/api/home/finance1/v2/collectiveAssetSummary',
    method: 'get',
    params: parms,
  });
}

// 预警中心-右1-村集体合同情况
export function contractionInfoSummary (parms) {
  return request({
    url: '/api/home/finance1/v2/contractionInfoSummary',
    method: 'get',
    params: parms,
  });
}

// 预警中心-预警列表
export function financeWarningList (parms) {
  return request({
    url: '/api/home/finance1/v2/financeWarningList',
    method: 'get',
    params: parms,
  });
}

// 预警中心-右5-结款方式分析
export function contractionCollectionPayStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/contractionCollectionPayStatistics',
    method: 'get',
    params: parms,
  });
}

// 预警中心-右4-合同渠道分析
export function contractionTypeStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/contractionTypeStatistics',
    method: 'get',
    params: parms,
  });
}

// 预警中心-中2-固定资产分布
export function assetDeptStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/assetDeptStatistics',
    method: 'get',
    params: parms,
  });
}

// 预警中心-中3-资源性资产分布
export function resourceDeptStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/resourceDeptStatistics',
    method: 'get',
    params: parms,
  });
}

// 预警中心-中4-固定资产构成分析
export function assetTypeStatistics (parms) {
  return request({
    url: '/api/home/finance1/v2/assetTypeStatistics',
    method: 'get',
    params: parms,
  });
}
